<?php
declare(strict_types=1);

namespace app\common\business;

use app\common\model\mysql\Category as CategoryModel;

class Category
{
    public $categoryObj = null;

    public function __construct()
    {
        $this->categoryObj = new CategoryModel();
    }

    /**
     * 新增一条分类
     * @param array $data
     * @return mixed
     * @throws \think\Exception
     */
    public function add(array $data)
    {
        $data['status'] = config('status.mysql.table_normal');

        $name = $data['name'];
        $count = $this->categoryObj->where('name', $name)->count();
        if ($count > 0) {
            throw new \think\Exception('分类名已经存在');
        }

        try {
            $this->categoryObj->save($data);
        } catch (\Exception $e) {
            throw new \think\Exception('服务内部异常');
        }
        return $this->categoryObj->getLastInsID();
    }

    /**
     * 获取正常状态的分类
     * @return array|\think\Collection
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function getNormalCategory()
    {
        $field = "id, name, pid";
        $categorys = $this->categoryObj->getNormalCategory($field);
        if (!$categorys) {
            return [];
        }
        $categorys = $categorys->toArray();
        return $categorys;
    }

    /**
     * 分页获取分类列表
     * @param $data
     * @param $num
     * @return array
     * @throws \think\db\exception\DbException
     */
    public function getLists($data, $num)
    {
        $list = $this->categoryObj->getLists($data, $num);
        if (!$list) {
            return [];
        }
        return $list->toArray();
    }
}